pub(crate) fn find_compound(krate: CrateNum, name: &str) -> Option<CompoundSpec>Expand description
Look up a compound property by name, in the given crate’s namespace first, then the builtin namespace.
pub(crate) fn find_compound(krate: CrateNum, name: &str) -> Option<CompoundSpec>Look up a compound property by name, in the given crate’s namespace first, then the builtin namespace.